@@ -21,6 +21,25 @@ describe Flowdock do
     end
   end
 
+  describe "handle_response" do
+    it "parses a response body that contains an empty string" do
+      class TestResponse
+        attr_reader :body, :code
+
+        def initialize
+          @body = ""
+          @code = 200
+        end
+      end
+
+      class TestHelper
+        include Flowdock::Helpers
+      end
+
+      expect(TestHelper.new.handle_response(TestResponse.new)).to eq({})
+    end
+  end
+
   describe "with sending Team Inbox messages" do
     before(:each) do
       @token = "test"
@@ -224,6 +243,25 @@ describe Flowdock do
         @flow.push_to_team_inbox(:subject => "Hello World", :content => @example_content).should be_false
       }.should raise_error(Flowdock::ApiError)
     end
+
+    it "should raise error if backend returns 404 NotFound" do
+      lambda {
+        stub_request(:post, push_to_team_inbox_url(@token)).
+          with(:body => {
+            :source => "myapp",
+            :project => "myproject",
+            :format => "html",
+            :from_name => "Eric Example",
+            :from_address => "eric@example.com",
+            :reply_to => "john@example.com",
+            :subject => "Hello World",
+            :content => @example_content
+          }).
+          to_return(:body => "{}", :status => 404)
+
+        @flow.push_to_team_inbox(:subject => "Hello World", :content => @example_content).should be_false
+      }.should raise_error(Flowdock::NotFoundError)
+    end
   end
 
   describe "with sending Chat messages" do
